@@ -1,5 +1,13 @@
 ABstat <-
 function(behavior,phaseX,v,statX){
+  os <- .Platform$OS.type
+  if (grepl("^darwin", R.version$os))
+    os <- "osx"
+  if (grepl("linux-gnu", R.version$os))
+    os <- "linux"
+  if (grepl("windows", R.version$os))
+    os <- "windows"
+  if (os =="osx") { 
   targetindex<-dev.cur() 
   targetindex<-recordPlot() 
   
@@ -26,4 +34,13 @@ function(behavior,phaseX,v,statX){
   
     
   {replayPlot(targetindex)}
-}
\ No newline at end of file
+  }
+  else {
+    writeLines("  ")
+    writeLines("ABstat() command is NOT available for Windows and Posit Cloud operating systems; instead use RSstat() command.") 
+    writeLines("For more information on annotating graphs go to the URL below:")
+    writeLines("https://www.dropbox.com/s/ex7ech9atz896yo/If%20you%20are%20using%20Windows%2010%20or%20RStudio%20Cloud.docx?dl=0")
+    
+  }
+  
+}
