@@ -3,7 +3,7 @@ function(behavior,phaseX,v1,v2) {
   mean1 <-tapply(behavior,phaseX,mean,na.rm=T)
   s1 <-tapply(behavior,phaseX, sd, na.rm=T)
  
- 
+  options(scipen=999)
   
   tphase<-table(phaseX)
   n1<- tphase[names(tphase)==v1]
@@ -15,6 +15,7 @@ function(behavior,phaseX,v1,v2) {
   DIFF<-mean1[names(mean1)==v1]-mean1[names(mean1)==v2]
  
   S<-sqrt(((n1*(s1[names(s1)==v1]^2)+(n2*s1[names(s1)==v2]^2))/totaln))
+ 
   CD<-(DIFF/S)
 
    V<-S^2
@@ -73,6 +74,8 @@ IV<-c(PA,PB)
   eschange=pnorm(es)-.5
   l5<-c("% change=",round(eschange,4)*100)
   print(c(pes1,l5))
+  
+  
   des<-abs(es1)
   esci<- d.ci(des,n2=ny,n1=nx)
   writeLines(" ")
@@ -81,13 +84,15 @@ IV<-c(PA,PB)
   
   writeLines("*****************d-index*******************************")
   cd1<-(round(abs(CD),5))
+  retcd<-cd1
   pcd1<-c("d-index=   ",cd1)
   dchange=pnorm(CD)-.5
   l6<-c("% change=",round(dchange,4)*100)
   
  dci<- d.ci(CD,n=nt,n2=ny,n1=nx)
- 
+
   print(c(pcd1,l6))
+ 
   writeLines(" ")
   print(dci)
   
@@ -105,8 +110,42 @@ print(Gci)
   print(round(rvalue,3))
   writeLines("*****************R-squared*****************************")
   print(round(rvalue2,3))
+  
+  SE<-sqrt((ny+nx)/(ny*nx)+((CD^2))/(2*(ny+nx-2))*(ny+nx)/(nx+ny-2))
+  
+  ret<-retrodesign(CD, SE, alpha = 0.05, df =totaln, n.sims = 10000)
+  writeLines(" ")
+  writeLines("*************************************************************************************************")
+  writeLines("Type M (Magnitude) and Type S (Sign) Errors by Andrew Gelman and John Carlin (2014)")
+  writeLines("In the graph, the dotted line is the actual effect size, and the full line is where")
+  writeLines("the statistic becomes statistically different from 0, given the standard error.")
+  writeLines("The grayed-out points aren't statisticaly significant, the squares are type M errors,") 
+  writeLines("and the triangles are type S Errors. Type M Errors shold be close to one and")
+  writeLines("Type S Errors close to zero.")
+  writeLines("*************************************************************************************************")
+  writeLines(" ")
+  power<-ret$power[1]
+  sign<-ret$type_s[1]
+  spercent<-sign*100
+  spercent<-round(spercent,1)
+  magnitude<-ret$type_m[1]
+  pret<-c("Power=",round(power,3))
+  mret<-c("Type M (Magnitude) Errors=",round(magnitude,3))
+  sret<-c("Type S Sign) Errors=",round(sign,3),spercent,"percent")
+  cat(sprintf(pret),"\n") 
+  cat(sprintf(mret),"\n") 
+  cat(sprintf(sret),"\n") 
+  writeLines("*************************************************************************************************")
+  writeLines(" ")
+
+  #dev.off()
+  par(mar = rep(2, 4))
+sim_plot(CD, SE, alpha = 0.05, df =totaln, n.sims = 10000,gg=F)
+ 
+  
   a<-readline("(s)ave, (a)ppend, or (n)either results? (s/a or n) ")
   
+  
   ES<-CD
  
   ES=data.frame(ES)
